<?php
// {{{ function cleanInput()
function cleanInput($input) {
	if (is_array($input)) {
		foreach($input as $var=>$val) { $input[$var] = cleanInput($val); }
	}
	else {
		$input = htmlspecialchars(strip_tags(trim($input)));
	}

	return $input;
}
// function cleanInput() }}}
// {{{ function buildThumbs()
function buildThumbs($directory,$file,$maxWidth,$maxHeight,$completeThumbPath) {
	$extension = explode(".", $file);
	
	if (strtolower($extension[1]) == 'jpg' || strtolower($extension[1]) == 'jpeg')
		$originalImage = imagecreatefromjpeg($directory . '/' . $file);
	elseif (strtolower($extension[1]) == 'png')
		$originalImage = imagecreatefrompng($directory . '/' . $file);
	elseif (strtolower($extension[1]) == 'gif')
		$originalImage = imagecreatefromgif($directory . '/' . $file);

	$oSize = getimagesize($directory . '/' . $file);
	$oWidth = $oSize[0];
	$oHeight = $oSize[1];

	if ( $oWidth < $maxWidth || $oHeight < $maxHeight)
		return false;		// Don't create a thumbnail if it's too small
	elseif ($oWidth >= $oHeight) {
		$thumbWidth = $maxWidth;
		$thumbHeight = $thumbWidth * ($oHeight / $oWidth);
	}
	elseif ($oHeight > $oWidth) {
		$thumbHeight = $maxHeight;
		$thumbWidth = $thumbHeight * ($oWidth / $oHeight);
	}
					
	$thumbnailImage = imagecreatetruecolor($thumbWidth,$thumbHeight); 
	imagecopyresampled($thumbnailImage,$originalImage,0,0,0,0,$thumbWidth,$thumbHeight,$oWidth,$oHeight);
	
	if (strtolower($extension[1]) == 'jpg' || strtolower($extension[1]) == 'jpeg')
		imagejpeg($thumbnailImage,$completeThumbPath, 95);
	elseif (strtolower($extension[1]) == 'png')
		imagepng($thumbnailImage,$completeThumbPath);
	elseif (strtolower($extension[1]) == 'gif')
		imagegif($thumbnailImage,$completeThumbPath);
					
	// Cleanup
	imagedestroy($thumbnailImage);
	imagedestroy($originalImage);
	return true;
}
// function buildThumbs() }}}
// {{{ function createIcon()
function createIcon($path,$directory,$file,$leftoffset,$topoffset) {
	if ( file_exists($path . '/' . $directory . '/icon.png') ) { unlink($path . '/' . $directory . '/icon.png'); }
	$iconWidth = '87';
	$iconHeight = '86';
	$icon = imagecreatefrompng($path . '/icon-blank.png');
	$oImageName = $path . '/' . $directory . '/' . $file;
	if ( !is_numeric($leftoffset) ) { $leftoffset = 0; }
	if ( !is_numeric($topoffset) ) { $topoffset = 0; }

	$originalImage = imagecreatefromjpeg($oImageName);
	$oSize = getimagesize($oImageName);
	$oWidth = $oSize[0];
	$oHeight = $oSize[1];

	if ( $oWidth < $iconWidth || $oHeight < $iconHeight)		// Don't create the icon if the image is too small
		return false;
	
	if ($oHeight >= $oWidth) {
		$tempWidth = $iconWidth;
		$tempHeight = $tempWidth * ($oHeight / $oWidth);
	}
	else if ($oWidth > $oHeight) {
		$tempHeight = $iconHeight;
		$tempWidth = $tempHeight * ($oWidth / $oHeight);
	}
	$tempImage = imagecreatetruecolor($tempWidth,$tempHeight);
	imagealphablending($tempImage, false);
	imagecopyresampled($tempImage,$originalImage,0,0,0,0,$tempWidth,$tempHeight,$oWidth,$oHeight);

	$new_image = imagecopymerge($icon,$tempImage,47,40,$leftoffset,$topoffset,$iconWidth,$iconHeight,100);
	imagesavealpha($icon, true);
	imagepng($icon, $path . '/' . $directory . '/icon.png');

	imagedestroy($tempImage);
	imagedestroy($icon);
}
// function createIcon() }}}
/* {{{ function rotateImage() */
function rotateImage($originalImage,$orientation) {
	/* {{{ Image Rotating (Depricated)
	//If rotating the original image and recreating
						
	if($orientation != 1) { 
		$originalImage = rotateImage($originalImage,$orientation);
		imagejpeg($originalImage,$image);
							
		$thumbnailImage = imagecreatetruecolor($thumbHeight,$thumbWidth); 
		imagecopyresampled($thumbnailImage,$originalImage,0,0,0,0,$thumbHeight,$thumbWidth,$oHeight,$oWidth);
	}
	else if ($orientation == 1) { 
		$thumbnailImage = imagecreatetruecolor($thumbWidth, $thumbHeight); 
		imagecopyresampled($thumbnailImage,$originalImage,0,0,0,0,$thumbWidth,$thumbHeight,$oWidth,$oHeight);
	}
// Image Rotating }}} */
		
	if ($orientation == 3) { $originalImage = imagerotate($originalImage, 180, 0); }
	else if ( $orientation == 4) { $originalImage = imagerotate($originalImage, 180, 0); }
	else if ( $orientation == 5) { $originalImage = imagerotate($originalImage, 270, 0); }
	else if ( $orientation == 6) { $originalImage = imagerotate($originalImage, 90, 0); }
	else if ( $orientation == 8) { $originalImage = imagerotate($originalImage, 90, 0); }
	return $originalImage;
}
/* function rotateImage() }}} */
// {{{ function pagination()
function pagination($link,$page,$totalPages) {
	$previousPage = $page - 1;
	$nextPage = $page + 1;
	$return = "";
	
	if ($page != 0) {
		// Previous Page and First Page Links
		if ($page != 1 && $totalPages > 1) {
			$return .= "<a href='" . $link . "1' title='First Page'>&laquo; First</a> ";
			$return .= "<a href='$link$previousPage' title='Previous Page'>&lt; Previous</a> ";
		}

		// Display Pagination Links
		if ($totalPages != 1) {
			$dotsBefore = 0;
			$dotsAfter = 0;
			for ($i = 1; $i <= $totalPages; $i++) {
				if ($i == $page) { $return .= "<span id='currentPage'>$i</span> "; }
	
				if ((($i <= 2) || ($i < $page && $i >= ($page - 2)) || ($i > $page && $i <= ($page + 2)) || ($i > ($totalPages - 2))) && ($i != $page)) {
					$return .= "<a href='$link$i' title='Page $i'>$i</a> ";
				}
				else if ($i < $page) {
					if ($dotsBefore == 0) {
						$dotsBefore = 1;
						$return .= " <a>...</a> ";
					}
				}
				else if ($i > $page) {
					if ($dotsAfter == 0) {
						$dotsAfter = 1;
						$return .= " <a>...</a> ";
					}
				}
			}
		}

		// Next Page, Last Page Links, and All Images Links
		if ($page != $totalPages && $totalPages > 1) {
			$return .= "<a href='$link$nextPage' title='Next Page'>Next &gt;</a> ";
			$return .= "<a href='$link$totalPages' title='Last Page'>Last &raquo;</a> ";
		}
		if ($totalPages > 1) { $return .= "<a href='$link" . "0' title='All Images'>All</a> "; }
	
		return $return;
	}
}
// }}}
?>
